@@ -303,7 +303,7 @@ def predict(last_layer, data_inputs, problem_type="classification"):
     if len(weights) != len(activations):
         raise TypeError("The length of layers {num_layers} is not equal to the number of activations functions {num_activations} and they must be equal.".format(num_layers=len(weights), num_activations=len(activations)))
 
-    predictions = numpy.zeros(shape=(data_inputs.shape[0]))
+    predictions = []
     for sample_idx in range(data_inputs.shape[0]):
         r1 = data_inputs[sample_idx, :]
         for curr_weights, activation in zip(weights, activations):
@@ -322,7 +322,7 @@ def predict(last_layer, data_inputs, problem_type="classification"):
         else:
             prediction = r1
 
-        predictions[sample_idx] = prediction
+        predictions.append(prediction)
 
     return predictions
 
